Module error

Module error 

Pepper sync error module

Structs

EncodingInvalid
The encoding of a compact Sapling output or compact Orchard action was invalid.

Enums

CompactFormatError
An error indicating that a field of a compact format structure could not be parsed.
ContinuityError
Block continuity errors.
MempoolError
Mempool errors.
ScanError
Scan errors.
ServerError
Server errors.
SyncError
Top level error enumerating any error that may occur during sync
SyncModeError
Sync mode error.
SyncRecoveryObservables
Recommended action when sync fails.
SyncStatusError
Sync status errors.