pub enum SyncError<E>{
MempoolError(MempoolError),
ScanError(ScanError),
ServerError(ServerError),
SyncModeError(SyncModeError),
ChainError(u32, u32, u32),
BirthdayBelowSapling(u32, u32),
ShardTreeError(ShardTreeError<Infallible>),
TruncationError(BlockHeight, PoolType),
TransparentAddressDerivationError(Error),
WalletError(E),
}Expand description
Top level error enumerating any error that may occur during sync
Variants
MempoolError(MempoolError)
Mempool error.
ScanError(ScanError)
Scan error.
ServerError(ServerError)
Server error.
SyncModeError(SyncModeError)
Sync mode error.
ChainError(u32, u32, u32)
Chain error.
BirthdayBelowSapling(u32, u32)
Birthday below sapling error.
ShardTreeError(ShardTreeError<Infallible>)
Shard tree error.
TruncationError(BlockHeight, PoolType)
Critical non-recoverable truncation error due to missing shard tree checkpoints.
TransparentAddressDerivationError(Error)
Transparent address derivation error.
WalletError(E)
Wallet error.
Implementations
Sourceimpl<E: Debug + Display> SyncError<E>
impl<E: Debug + Display> SyncError<E>
Sourcepub fn recommend_same_server(&self) -> bool
pub fn recommend_same_server(&self) -> bool
Returns true if this error is likely transient and retrying sync
(possibly against a different server) may succeed.
Server errors from failed gRPC requests and mempool stream failures are recommend_same_server. Configuration errors, wallet corruption, and data integrity failures are not.
Sourceimpl<E: Debug + Display> SyncError<E>
impl<E: Debug + Display> SyncError<E>
Sourcepub fn recovery_recommendation(&self) -> SyncRecoveryObservables
pub fn recovery_recommendation(&self) -> SyncRecoveryObservables
Returns the recommended recovery action for this error.
This is the primary entry point for callers that need to decide whether to retry, switch servers, or give up.