WalletTransaction

Struct WalletTransaction 

pub struct WalletTransaction { /* private fields */ }
Wallet transaction

Implementations

Source

impl WalletTransaction

pub fn read<R: Read>( reader: R, consensus_parameters: &impl Parameters, ) -> Result<Self>

Deserialize into reader

pub fn write<W: Write>( &self, writer: W, consensus_parameters: &impl Parameters, ) -> Result<()>

Serialize into writer

Source

impl WalletTransaction

pub fn txid(&self) -> TxId

Transaction ID

pub fn status(&self) -> ConfirmationStatus

Confirmation status

pub fn transaction(&self) -> &Transaction

pub fn datetime(&self) -> u32

Datetime. In form of seconds since unix epoch.

pub fn transparent_coins(&self) -> &[TransparentCoin]

Transparent coins

pub fn transparent_coins_mut(&mut self) -> Vec<&mut TransparentCoin>

Transparent coins mutable

pub fn sapling_notes(&self) -> &[SaplingNote]

Sapling notes

pub fn sapling_notes_mut(&mut self) -> Vec<&mut SaplingNote>

Sapling notes mutable

pub fn orchard_notes(&self) -> &[OrchardNote]

Orchard notes

pub fn orchard_notes_mut(&mut self) -> Vec<&mut OrchardNote>

Orchard notes mutable

pub fn outgoing_sapling_notes(&self) -> &[OutgoingSaplingNote]

Outgoing sapling notes

pub fn outgoing_orchard_notes(&self) -> &[OutgoingOrchardNote]

Outgoing orchard notes

pub fn sapling_nullifiers(&self) -> Vec<&Nullifier>

Returns nullifers from sapling bundle. Returns empty vec if bundle is None.

pub fn orchard_nullifiers(&self) -> Vec<&Nullifier>

Returns nullifers from orchard bundle. Returns empty vec if bundle is None.

pub fn outpoints(&self) -> Vec<&OutPoint>

Returns outpoints from transparent bundle. Returns empty vec if bundle is None.

pub fn update_status(&mut self, status: ConfirmationStatus, datetime: u32)

Updates transaction status if status is a valid update for the current transaction status. For example, if status is Mempool but the current transaction status is Confirmed, the status will remain unchanged. datetime refers to the time in which the status was updated, or the time the block was mined when updating to Confirmed status.

Source

impl WalletTransaction

pub fn total_value_sent(&self) -> u64

Returns the total value sent to receivers, excluding value sent to the wallet’s own addresses.

pub fn total_value_received(&self) -> u64

Returns total sum of all output values.

pub fn total_output_value<Op: OutputInterface>(&self) -> u64

Returns total sum of output values for a given pool.

pub fn total_outgoing_note_value<Op: OutgoingNoteInterface>(&self) -> u64

Returns total sum of outgoing note values for a given shielded pool.