NoteInterface

Trait NoteInterface 

pub trait NoteInterface: OutputInterface {
    type ZcashNote;
    type Nullifier: Copy;

    const SHIELDED_PROTOCOL: ShieldedProtocol;

    // Required methods
    fn note(&self) -> &Self::ZcashNote;
    fn nullifier(&self) -> Option<Self::Nullifier>;
    fn position(&self) -> Option<Position>;
    fn memo(&self) -> &Memo;
    fn refetch_nullifier_ranges(&self) -> &[Range<BlockHeight>];
}
Provides a common API for all shielded output types.

Required Associated Constants

const SHIELDED_PROTOCOL: ShieldedProtocol

Note’s associated shielded protocol.

Required Associated Types

type ZcashNote

Decrypted note type.

type Nullifier: Copy

Nullifier type.

Required Methods

fn note(&self) -> &Self::ZcashNote

Decrypted note with recipient and value

fn nullifier(&self) -> Option<Self::Nullifier>

Derived nullifier

fn position(&self) -> Option<Position>

Commitment tree leaf position

fn memo(&self) -> &Memo

Memo

fn refetch_nullifier_ranges(&self) -> &[Range<BlockHeight>]

List of block ranges where the nullifiers must be re-fetched to guarantee the note has not been spent. These scan ranges were marked ScannedWithoutMapping or RefetchingNullifiers priority before this note was scanned, meaning the nullifiers were discarded due to memory constraints and will be re-fetched later in the sync process.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors