pub fn scan_pending_transaction<W>(
consensus_parameters: &impl Parameters,
ufvks: &HashMap<AccountId, UnifiedFullViewingKey>,
wallet: &mut W,
transaction: Transaction,
status: ConfirmationStatus,
datetime: u32,
) -> Result<(), SyncError<W::Error>>where
W: SyncWallet + SyncBlocks + SyncTransactions + SyncNullifiers + SyncOutPoints + SyncShardTrees,Expand description
Scans a pending transaction of a given status, adding to the wallet and updating output spend statuses.
Used both internally for scanning mempool transactions and externally for scanning calculated and transmitted transactions during send.
Panics if status is of Confirmed variant.